@@ -33,3 +33,6 @@ class TranslatableMessages(metaclass=TranslatableMessagesMeta):
 
     def __str__(self):
         return self.key
+
+    def __eq__(self, other: "TranslatableMessages"):
+        return self.key == other.key and self.placeholders == other.placeholders
