@@ -17,7 +17,7 @@ def fetch_translatable_strings(resource: Dict):
 def translate(resource: Dict, translated_strings: Dict):
     def _translate(obj: dict):
         if isinstance(obj, TranslatableMessages):
-            return translated_strings.get(str(obj))
+            return translated_strings.get(obj.key, "").format(**obj.placeholders)
         if isinstance(obj, list):
             return [_translate(val) for val in obj]
         if isinstance(obj, dict):
