@@ -151,3 +151,12 @@ def test_formatted_string_translation():
         )
         == "Hey Dhruv"
     )
+
+
+def test_comparison_in_formatted_string():
+    class FakeMessages(TranslatableMessages):
+        NAME = "cb.name"
+
+    assert FakeMessages.NAME.format(name="Rameez") == FakeMessages.NAME.format(
+        name="Rameez"
+    )
